@@ -98,7 +98,7 @@ class DockerLocalNodeTags:
             except Exception:
                 # Avoids a transient error during cluster shutdown.
                 # TODO (dmitri): Fix for real!
-                logger.error("Failed to read node tags!" "Returning an empty dict.")
+                logger.error("Failed to read node tags." "Returning an empty dict.")
                 return {}
 
     def set(self, node_id: str, tags: Dict[str, str]) -> None:
