@@ -78,7 +78,7 @@ def wrap_api_client_with_retries(api_client: DefaultApi) -> DefaultApi:
                 return func(*args, **kwargs)
             except (ConnectionResetError, HTTPError) as e:
                 if i == (RETRY_COUNT - 1):
-                    logger.error(f"{func.__name__} FAILED {RETRY_COUNT} times!")
+                    logger.error(f"{func.__name__} FAILED {RETRY_COUNT} times")
                     raise e
                 time.sleep(0.1 * i)
                 continue
@@ -93,18 +93,26 @@ class AnyscaleInstanceManagerNodeProvider:
     """NodeProvider for managing nodes with instance manager.
     """
 
-    def __init__(self, provider_config: Dict[str, Any], cluster_name: str) -> None:
+    def __init__(
+        self,
+        provider_config: Dict[str, Any],
+        cluster_name: str,
+        api_client: Optional[DefaultApi] = None,
+    ) -> None:
         self.provider_config = provider_config
         self.inner_provider_config = provider_config["inner_provider"]
         self.inner_provider = _get_node_provider(
             self.inner_provider_config, cluster_name
         )
         self.cloud_id = self.inner_provider_config["cloud_id"]
-        cli_token = self.inner_provider_config["cli_token"]
         host = self.inner_provider_config["host"]
-        self.api_client = wrap_api_client_with_retries(
-            get_auth_api_client(cli_token=cli_token, host=host).api_client
-        )
+        if api_client is None:
+            cli_token = self.inner_provider_config["cli_token"]
+            self.api_client = wrap_api_client_with_retries(
+                get_auth_api_client(cli_token=cli_token, host=host).api_client
+            )
+        else:
+            self.api_client = api_client
         self.is_provider_supported = self._is_provider_supported()
 
     def _is_provider_supported(self) -> bool:
