@@ -40,7 +40,8 @@ class BlockLogger:
             self.close_block()
         self.current_block = block_label
         print(
-            f"{colorama.Style.BRIGHT}{colorama.Fore.CYAN}{block_title if block_title else block_label}{colorama.Style.RESET_ALL}"
+            f"{colorama.Style.BRIGHT}{colorama.Fore.CYAN}{block_title if block_title else block_label}{colorama.Style.RESET_ALL}",
+            file=sys.stderr,
         )
 
     def close_block(self, block_label: Optional[str] = None) -> None:
@@ -57,7 +58,7 @@ class BlockLogger:
                 self.current_block == block_label
             ), f"Attempting to close block {block_label}, but block {self.current_block} is currently open."
         self.current_block = None
-        print()
+        print(file=sys.stderr)
 
     @staticmethod
     def highlight(word: str) -> str:
@@ -137,8 +138,6 @@ class BlockLogger:
         output += "{}s".format(round(delta, 1))
         return output
 
-
-class _ConsoleLog(BlockLogger):
     def error(self, *msg: str) -> None:
         print(
             "{}{}(anyscale +{}){} ".format(
@@ -153,7 +152,7 @@ class _ConsoleLog(BlockLogger):
         print(*msg, file=sys.stderr)
 
 
-class LogsLogger(_ConsoleLog):
+class LogsLogger(BlockLogger):
     """ This logger is used to print customer logs to STDOUT with no decoration
     """
 
