@@ -111,7 +111,7 @@ def get_last_used_cloud(
             cloud = anyscale_api_client.get_cloud(cloud_id).result
         except Exception:
             raise click.ClickException(
-                f"Failed to fetch Cloud with id: {cloud_id}. Please specify cloud_name in the command."
+                f"Failed to fetch Cloud with id: {cloud_id}. Please specify `cloud` in the command."
             )
     else:
         # TODO(nikita): Add some logics or checks here so users don't start clusters with clouds
@@ -129,7 +129,7 @@ def get_last_used_cloud(
     log.info(
         (
             f"Using last active cloud '{cloud_name}'. "
-            "Specify cloud_name in the command to overwrite."
+            "Specify `cloud` in the command to overwrite."
         )
     )
     return cast(str, cloud_name)
