@@ -92,7 +92,6 @@ def cloud_set_default(
 @click.option(
     "--yes", "-y", is_flag=True, default=False, help="Don't ask for confirmation."
 )
-@click.option("--legacy/--no-legacy", default=True, hidden=True)
 @click.option(
     "--gcp-folder-id",
     help="Folder ID where the 'Anyscale'  folder will be created.",
@@ -115,14 +114,12 @@ def setup_cloud(
     region: str,
     name: str,
     yes: bool,
-    legacy: bool,
     gcp_folder_id: Optional[int],
     vpc_peering_ip_range: Optional[str],
     vpc_peering_target_project_id: Optional[str],
     vpc_peering_target_vpc_id: Optional[str],
 ) -> None:
     CloudController().setup_cloud(
-        is_k8s=not legacy,
         provider=provider,
         region=region,
         name=name,
