@@ -1,13 +1,13 @@
+import os
 from typing import Optional
 
 import click
 
 from anyscale.controllers.cluster_controller import ClusterController
-from anyscale.feature_flags import FLAG_KEY_ENABLE_BYOD
-from anyscale.util import check_is_feature_flag_on, validate_non_negative_arg
+from anyscale.util import validate_non_negative_arg
 
 
-HIDE_BYOD_FLAGS = not check_is_feature_flag_on(FLAG_KEY_ENABLE_BYOD)
+HIDE_BYOD_FLAGS = os.getenv("ANYSCALE_BYOD") != "1"
 
 
 @click.group("cluster", help="Interact with clusters on Anyscale.")
@@ -80,7 +80,7 @@ def cluster_cli() -> None:
     default=None,
     help=(
         "Id of existing cluster to restart. This argument can be used "
-        "to interact with any cluster you have access to across projects."
+        "to interact with any cluster you have access to in any project."
     ),
 )
 @click.option(
@@ -191,7 +191,7 @@ def start(
     default=None,
     help=(
         "Id of existing cluster to termiante. This argument can be used "
-        "to interact with any cluster you have access to across projects."
+        "to interact with any cluster you have access to in any project."
     ),
 )
 @click.option(
@@ -227,6 +227,57 @@ def terminate(
     )
 
 
+@cluster_cli.command(name="archive", help="Archive a cluster on Anyscale.")
+@click.option(
+    "--name",
+    "-n",
+    required=False,
+    default=None,
+    help="Name of existing cluster to archive.",
+)
+@click.option(
+    "--cluster-id",
+    "--id",
+    required=False,
+    default=None,
+    help=(
+        "Id of existing cluster to archive. This argument"
+        "can be used to archive any cluster you have access to in any project."
+    ),
+)
+@click.option(
+    "--project-id",
+    required=False,
+    default=None,
+    help=(
+        "Override project id used for this cluster. If not provided, the Anyscale project "
+        "context will be used if it exists. Otherwise a default project will be used."
+    ),
+)
+@click.option(
+    "--project",
+    required=False,
+    default=None,
+    help=(
+        "Override project name used for this cluster. If not provided, the Anyscale project "
+        "context will be used if it exists. Otherwise a default project will be used."
+    ),
+)
+def archive(
+    name: Optional[str],
+    cluster_id: Optional[str],
+    project_id: Optional[str],
+    project: Optional[str],
+) -> None:
+    cluster_controller = ClusterController()
+    cluster_controller.archive(
+        cluster_name=name,
+        cluster_id=cluster_id,
+        project_id=project_id,
+        project_name=project,
+    )
+
+
 @cluster_cli.command(
     name="list",
     help=(
@@ -248,7 +299,7 @@ def terminate(
     default=None,
     help=(
         "Id of existing cluster get information about. This argument can be used "
-        "to interact with any cluster you have access to across projects."
+        "to interact with any cluster you have access to in any project."
     ),
 )
 @click.option(
@@ -273,7 +324,7 @@ def terminate(
     "--include-all-projects",
     is_flag=True,
     default=False,
-    help="List all active clusters user has access to across projects.",
+    help="List all active clusters user has access to in any project.",
 )
 @click.option(
     "--include-inactive",
@@ -281,6 +332,15 @@ def terminate(
     default=False,
     help="List clusters of all states.",
 )
+@click.option(
+    "--include-archived",
+    is_flag=True,
+    default=False,
+    help=(
+        "List archived clusters as well as unarchived clusters."
+        "If not provided, defaults to listing only unarchived clusters."
+    ),
+)
 @click.option(
     "--max-items",
     required=False,
@@ -296,6 +356,7 @@ def list(
     project: Optional[str],
     include_all_projects: bool,
     include_inactive: bool,
+    include_archived: bool,
     max_items: int,
 ) -> None:
     cluster_controller = ClusterController()
@@ -306,5 +367,6 @@ def list(
         project_name=project,
         include_all_projects=include_all_projects,
         include_inactive=include_inactive,
+        include_archived=include_archived,
         max_items=max_items,
     )
