@@ -68,6 +68,11 @@ changes, then upload those changes to a currently running cluster.""",
 )
 def anyscale_clone(project_name: str, owner: Optional[str]) -> None:
     project_controller = ProjectController()
+    message = (
+        "Warning: `anyscale clone` has been deprecated and will be removed in the future. "
+        "Please use `anyscale project init --project-id [project_id]` to connect to an existing project."
+    )
+    project_controller.log.warning(message)
     project_controller.clone(project_name, owner=owner)
 
 
