@@ -25,24 +25,13 @@ def service_cli() -> None:
 @click.option(
     "--description", required=False, default=None, help="Description of service."
 )
-@click.option(
-    "--do-apply",
-    required=False,
-    is_flag=True,
-    default=False,
-    hidden=True,
-    help="Feature flag to support updating a service",
-)
 def deploy(
-    service_config_file: str,
-    name: Optional[str],
-    description: Optional[str],
-    do_apply: Optional[bool],
+    service_config_file: str, name: Optional[str], description: Optional[str],
 ) -> None:
     # TODO[Bruce]: Remove update flag once fully test apply function.
     service_controller = ServiceController()
     service_controller.deploy(
-        service_config_file, name=name, description=description, do_apply=do_apply,
+        service_config_file, name=name, description=description,
     )
 
 
