@@ -140,16 +140,21 @@ def session_finish_command(command_id: str, stop: bool, terminate: bool) -> None
 @click.option(
     "--auth-token", help="Token for authentication proxy", type=str, required=False
 )
-def auth_start(auth_token: Optional[str]) -> None:
+@click.option(
+    "--user-service-token", help="Token for user service", type=str, required=False
+)
+def auth_start(auth_token: Optional[str], user_service_token: Optional[str]) -> None:
     from aiohttp import web
 
     # TODO(pcm): Make this required and pass in after the Docker image is migrated.
     if not auth_token:
         auth_token = os.environ["ANYSCALE_AUTH_TOKEN"]
+    if not user_service_token:
+        user_service_token = os.environ.get("ANYSCALE_USER_SERVICE_TOKEN")
 
     assert auth_token, "Auth Token must be set by parameter or environment variable."
 
-    auth_proxy_app = make_auth_proxy_app(auth_token)
+    auth_proxy_app = make_auth_proxy_app(auth_token, user_service_token)
     web.run_app(auth_proxy_app)
 
 
