@@ -1,5 +1,5 @@
 import os
-from typing import Optional
+from typing import Any, Optional
 
 import click
 
@@ -7,9 +7,18 @@ from anyscale.authenticate import get_auth_api_client
 from anyscale.client.openapi_client.models.create_experimental_workspace import (
     CreateExperimentalWorkspace,
 )
+from anyscale.client.openapi_client.models.execute_shell_command_options import (
+    ExecuteShellCommandOptions,
+)
 from anyscale.controllers.cluster_controller import ClusterController
 from anyscale.controllers.project_controller import ProjectController
 from anyscale.controllers.workspace_controller import WorkspaceController
+from anyscale.project import (
+    find_project_root,
+    get_proj_name_from_id,
+    write_project_file_to_disk,
+)
+from anyscale.util import get_endpoint
 
 
 ANYSCALE_WORKSPACES_SSH_OPTIONS = [
@@ -27,7 +36,9 @@ def workspace_cli() -> None:
     pass
 
 
-@workspace_cli.command(name="create", help="Create a workspace on Anyscale.")
+@workspace_cli.command(
+    name="create", help="Create a workspace on Anyscale.", hidden=True
+)
 @click.option(
     "--name", "-n", required=True, help="Name of the workspace to create.",
 )
@@ -49,7 +60,9 @@ def create(
     )
 
 
-@workspace_cli.command(name="start", help="Start an existing workspace on Anyscale.")
+@workspace_cli.command(
+    name="start", help="Start an existing workspace on Anyscale.", hidden=True
+)
 @click.option(
     "--name",
     "-n",
@@ -77,7 +90,9 @@ def start(name: Optional[str],) -> None:
     )
 
 
-@workspace_cli.command(name="terminate", help="Terminate a workspace on Anyscale.")
+@workspace_cli.command(
+    name="terminate", help="Terminate a workspace on Anyscale.", hidden=True
+)
 @click.option(
     "--name",
     "-n",
@@ -103,13 +118,55 @@ def terminate(name: Optional[str],) -> None:
     default=None,
     help="Name of existing workspace to clone.",
 )
-def clone(name: Optional[str],) -> None:
+def clone(name: str) -> None:
+    _check_local()
+
+    workspace = get_workspace_from_name(name)
+    project_id = workspace.project_id
+    auth_api_client = get_auth_api_client()
+    dest = get_proj_name_from_id(
+        project_id=project_id, api_client=auth_api_client.api_client
+    )
     project_controller = ProjectController()
-    project_controller.clone(f"workspace-project-{name}", owner=None)
-    os.chdir(f"workspace-project-{name}")
+    if os.path.exists(dest):
+        _exit_error(
+            f"Cannot clone workspace: already cloned locally at '{os.path.abspath(dest)}'."
+        )
+    project_controller.clone(dest, owner=None)
+    os.chdir(dest)
     _do_pull(pull_git_state=True)
 
 
+@workspace_cli.command(name="activate")
+@click.argument(
+    "name", required=True, default=None,
+)
+def activate(name: str) -> None:
+    """Activate a workspace.
+
+    If the current directory is already a part of a workspace, change the workspace.
+    Else, setup a new workspace rooted at the current directory
+
+    Args:
+        name: Name of the workspace to activate.
+    """
+    _check_local()
+    root_dir = find_project_root(os.getcwd())
+    if not root_dir:
+        raise click.ClickException(
+            "Could not find the root workspace directory. Please first run `anyscale workspace clone`"
+        )
+    try:
+        workspace = get_workspace_from_name(name)
+        id = workspace.project_id
+    except Exception:
+        workpaces_url = get_endpoint("/workspaces")
+        raise click.ClickException(
+            f"There is no workspace {name} registered with Anyscale. You can view your workspaces here: {workpaces_url}"
+        )
+    write_project_file_to_disk(id, root_dir)
+
+
 @workspace_cli.command(name="pull", help="Pull files from a workspace on Anyscale.")
 @click.option(
     "--pull-git-state",
@@ -119,6 +176,8 @@ def clone(name: Optional[str],) -> None:
     help="Also pull git state. This will add additional overhead.",
 )
 def pull(pull_git_state) -> None:
+    _check_local()
+    _check_workspace()
     _do_pull(pull_git_state)
 
 
@@ -131,6 +190,8 @@ def pull(pull_git_state) -> None:
     help="Also push git state. This is currently unoptimized and will be very slow.",
 )
 def push(push_git_state) -> None:
+    _check_local()
+    _check_workspace()
     _do_push(push_git_state)
 
 
@@ -138,6 +199,14 @@ def push(push_git_state) -> None:
     name="run", help="Run a command in a workspace, syncing files first if needed."
 )
 @click.argument("command", required=True)
+@click.option(
+    "--web-terminal",
+    "-w",
+    required=False,
+    is_flag=True,
+    default=False,
+    help="Run the command in the webterminal. Progress can be tracked from the UI.",
+)
 @click.option(
     "--as-job",
     "-j",
@@ -154,7 +223,9 @@ def push(push_git_state) -> None:
     default=False,
     help="Whether to skip pushing files prior to running the command.",
 )
-def run(command: str, as_job: bool, no_push: bool,) -> None:
+def run(command: str, web_terminal: bool, as_job: bool, no_push: bool,) -> None:
+    _check_local()
+    _check_workspace()
     if as_job:
         raise NotImplementedError("Running as a job isn't implemented yet.")
     workspace_controller = WorkspaceController()
@@ -162,9 +233,26 @@ def run(command: str, as_job: bool, no_push: bool,) -> None:
     # their latest file changes.
     if not no_push:
         _do_push(push_git_state=False)
-    workspace_controller.run_cmd(
-        ANYSCALE_WORKSPACES_SSH_OPTIONS, f"cd ~/workspace-project-* && {command}",
-    )
+    if web_terminal:
+        workspace_controller = WorkspaceController()
+        auth_api_client = get_auth_api_client()
+        results = auth_api_client.api_client.execute_shell_command_api_v2_sessions_session_id_execute_shell_command_post(
+            workspace_controller.session.id,
+            ExecuteShellCommandOptions(
+                shell_command=f"cd ~/workspace-project-* && {command}"
+            ),
+        )
+        # TODO(ekl) show the workspace URL here and also block on completion.
+        print()
+        print(
+            "Command submitted succcessfully! See the 'Command History' tab "
+            f"of this workspace to view command status and output: {results}"
+        )
+        print()
+    else:
+        workspace_controller.run_cmd(
+            ANYSCALE_WORKSPACES_SSH_OPTIONS, f"cd ~/workspace-project-* && {command}",
+        )
 
 
 def _do_pull(pull_git_state):
@@ -182,7 +270,8 @@ def _do_pull(pull_git_state):
         workspace_controller.project_definition.root,
         down=True,
         rsync_filters=[".gitignore"],
-        rsync_excludes=[".anyscale.yaml"] + ([] if pull_git_state else [".git"]),
+        rsync_excludes=[".anyscale.yaml", ".git/objects/info/alternates"]
+        + ([] if pull_git_state else [".git"]),
     )
 
 
@@ -197,5 +286,42 @@ def _do_push(push_git_state):
         # phases: first sync the shared git objects to EFS, then sync non .git files.
         # Otherwise this will be very slow since our local git representation is
         # different from the remote one (has large .pack files).
-        rsync_excludes=[".anyscale.yaml"] + ([] if push_git_state else [".git"]),
+        rsync_excludes=[".anyscale.yaml", ".git/objects/info/alternates"]
+        + ([] if push_git_state else [".git"]),
     )
+
+
+def _check_local():
+    if "ANYSCALE_WORKING_DIR" in os.environ:
+        _exit_error(
+            "Error: This command cannot be run from inside an Anyscale cluster."
+        )
+
+
+def _check_workspace():
+    if not os.path.exists(".anyscale.yaml"):
+        _exit_error(
+            "Error: This command must be run from the root of a cloned workspace directory."
+        )
+
+
+def get_workspace_from_name(name: str) -> Any:
+    """Get a workspace from its name.
+    """
+
+    # Find the workspace by name
+    auth_api_client = get_auth_api_client()
+    results = auth_api_client.api_client.list_workspaces_api_v2_experimental_workspaces_get(
+        name=name
+    ).results
+    if len(results) == 0:
+        _exit_error("No workspace with name {} found.".format(name))
+    elif len(results) > 1:
+        _exit_error("Multiple workspaces with name {} found.".format(name))
+    return results[0]
+
+
+def _exit_error(msg: str) -> None:
+    print()
+    print(msg)
+    exit(1)
