@@ -39,8 +39,9 @@ import yaml
 
 from anyscale.api import configure_open_api_client_headers
 from anyscale.authenticate import AuthenticationBlock, get_auth_api_client
-from anyscale.cli_logger import _ConsoleLog  # pylint:disable=private-import
+from anyscale.cli_logger import BlockLogger
 from anyscale.client.openapi_client.models.session import Session
+from anyscale.conf import MINIMUM_RAY_VERSION
 from anyscale.connect_utils.prepare_cluster import create_prepare_cluster_block
 from anyscale.connect_utils.project import create_project_block
 from anyscale.connect_utils.start_interactive_session import (  # pylint:disable=private-import
@@ -86,11 +87,6 @@ BUILD_STEPS = [
     "pip uninstall -y ray",
 ]
 
-# Minimum default Ray version to return when a user either asks for `anyscale.connect required_ray_version`
-# or when a Default Cluster Env is used
-# TODO(ilr/nikita) Convert this to a backend call for the most recent Ray Version in the Dataplane!
-MINIMUM_RAY_VERSION = "1.4.0"
-
 
 # Default docker images to use for connect clusters.
 def _get_base_image(image: str, ray_version: str, cpu_or_gpu: str) -> str:
@@ -123,6 +119,16 @@ def _is_running_on_anyscale_cluster() -> bool:
     return "ANYSCALE_SESSION_ID" in os.environ
 
 
+def _redact_token(token: str) -> str:
+    "Preserve a short prefix of the token, redact other characters."
+    preserve = 8
+    n = len(token)
+    if n <= preserve:
+        return token
+    redacted_len = 16
+    return token[:preserve] + ("*" * (redacted_len - preserve))
+
+
 class ClientBuilder:
     """This class lets you set cluster options and connect to Anyscale.
 
@@ -178,7 +184,7 @@ class ClientBuilder:
         if log:
             self._log = log
         else:
-            self._log = _ConsoleLog()
+            self._log = BlockLogger()
         if anyscale_sdk:
             self._anyscale_sdk = anyscale_sdk
         else:
@@ -188,7 +194,8 @@ class ClientBuilder:
                     anyscale.shared_anyscale_utils.conf.ANYSCALE_HOST
                 )
             )
-            self._log.debug("Using credentials {}".format(self._credentials[:6]))
+            redacted_token = _redact_token(self._credentials)
+            self._log.debug("Using credentials {}".format(redacted_token))
             self._anyscale_sdk = AnyscaleSDK(
                 self._credentials,
                 anyscale.shared_anyscale_utils.conf.ANYSCALE_HOST + "/ext",
@@ -1244,7 +1251,7 @@ class ClientBuilder:
         except Exception as e:
             self._log.error(f"Failed to get ClusterID with error: {e}")
             raise RuntimeError(
-                "Unable to get ClusterID for `download_results`!"
+                "Unable to get ClusterID for `download_results`."
             ) from None
         self._session_controller.pull(cluster_name, source=remote_dir, target=local_dir)
 
