@@ -281,7 +281,7 @@ class StartInteractiveSessionBlock:
             ray_info = None
             try:
                 self.log.info(
-                    "Connection Failed! Attempting to get Debug Information!",
+                    "Connection Failed. Attempting to get Debug Information.",
                     block_label=self.block_label,
                 )
                 py_command = """import ray; import json; print(json.dumps({"ray_commit" : ray.__commit__, "ray_version" :ray.__version__}))"""
@@ -375,7 +375,7 @@ class StartInteractiveSessionBlock:
             raise RuntimeError("Failed to acquire cluster we created")
 
         def func() -> str:
-            return "Connected!"
+            return "Connected."
 
         f_remote = self._ray.remote(func)
         ray_ref = f_remote.remote()
