@@ -4,48 +4,34 @@ Fetches data required and formats output for `anyscale cloud` commands.
 
 import ipaddress
 import json
-import os
-import time
+import secrets
 from typing import Any, Dict, Optional
 
 import boto3
-import botocore.exceptions
+import botocore
 from click import ClickException, INT, prompt
 
 from anyscale.aws_iam_policies import (
-    AMAZON_CLOUDWATCH_FULL_ACCESS_POLICY_ARN,
-    AMAZON_EC2_FULL_ACCESS_POLICY_ARN,
     AMAZON_ECR_READONLY_ACCESS_POLICY_ARN,
-    AMAZON_IAM_FULL_ACCESS_POLICY_ARN,
-    AMAZON_ROUTE53_FULL_ACCESS_POLICY_ARN,
     AMAZON_S3_FULL_ACCESS_POLICY_ARN,
-    AMAZON_VPC_FULL_ACCESS_POLICY_ARN,
-    ANYSCALE_IAM_ACCESS_POLICY_DOCUMENT,
-    ANYSCALE_IAM_ACCESS_POLICY_NAME,
-    EKS_FULL_ACCESS_POLICY_DOCUMENT,
-    EKS_FULL_ACCESS_POLICY_NAME,
+    ANYSCALE_IAM_PERMISSIONS_EC2_INITIAL_RUN,
+    ANYSCALE_IAM_PERMISSIONS_EC2_STEADY_STATE,
 )
 from anyscale.cli_logger import BlockLogger
-from anyscale.client.openapi_client.models import (
-    Cloud,
-    CloudConfig,
-    CloudProviders,
-    CloudResponse,
-    WriteCloud,
-)
+from anyscale.client.openapi_client.models import CloudConfig, WriteCloud
 from anyscale.cloud import get_cloud_id_and_name, get_cloud_json_from_id
 from anyscale.conf import ANYSCALE_IAM_ROLE_NAME
 from anyscale.controllers.base_controller import BaseController
 from anyscale.formatters import clouds_formatter
 from anyscale.util import (  # pylint:disable=private-import
     _CACHED_GCP_REGIONS,
+    _client,
     _get_role,
     _resource,
     _update_external_ids_for_policy,
     confirm,
     get_available_regions,
     launch_gcp_cloud_setup,
-    number_of_external_ids_in_policy,
 )
 
 
@@ -165,7 +151,6 @@ class CloudController(BaseController):
 
     def setup_cloud(
         self,
-        is_k8s: bool,
         provider: str,
         region: Optional[str],
         name: str,
@@ -188,10 +173,7 @@ class CloudController(BaseController):
                     f"Region '{region}' is not available. Regions available are: "
                     f"{', '.join(map(repr, regions_available))}"
                 )
-            if is_k8s:
-                self.setup_aws_k8s_cloud(region=region, name=name, yes=yes)
-            else:
-                self.setup_aws(region=region, name=name, yes=yes)
+            self.setup_aws(region=region, name=name, yes=yes)
         elif provider == "gcp":
             # If the region is blank, change it to the default for GCP.
             if region is None:
@@ -241,10 +223,9 @@ class CloudController(BaseController):
     def setup_aws(self, region: str, name: str, yes: bool = False) -> None:
         from ray.autoscaler._private.aws.config import DEFAULT_RAY_IAM_ROLE
 
-        os.environ["AWS_DEFAULT_REGION"] = region
-
         confirm(
-            "\nYou are about to give anyscale full access to EC2 and IAM, as well as readonly access to ECR, all in your AWS account.\n\n"
+            "\nYou are about to give Anyscale access to EC2 permissions necessary to manage clusters.\n"
+            "A separate AWS role is created for your clusters to run with \nand will be granted readonly access to ECR & S3 Full Access in your AWS account.\n\n"
             "Continue?",
             yes,
         )
@@ -252,12 +233,12 @@ class CloudController(BaseController):
         self.setup_aws_cross_account_role(region, name)
         self.setup_aws_ray_role(region, DEFAULT_RAY_IAM_ROLE)
 
-        self.log.info("AWS credentials setup complete!")
+        self.log.info("AWS credentials setup complete.")
         self.log.info(
             "You can revoke the access at any time by deleting anyscale IAM user/role in your account."
         )
         self.log.info(
-            "Head over to the web UI to create new sessions in your AWS account!"
+            "Head over to the web UI to create new sessions in your AWS account."
         )
 
     def setup_aws_cross_account_role(self, region: str, name: str) -> None:
@@ -276,43 +257,70 @@ class CloudController(BaseController):
             },
         }
 
-        role = _get_role(ANYSCALE_IAM_ROLE_NAME, region)
+        for _ in range(5):
+            role_name = "{}-{}".format(ANYSCALE_IAM_ROLE_NAME, secrets.token_hex(4))
 
-        role_exists = role is not None
-        if role is None:
-            iam = _resource("iam", region)
-            iam.create_role(
-                RoleName=ANYSCALE_IAM_ROLE_NAME,
-                AssumeRolePolicyDocument=json.dumps(anyscale_aws_iam_role_policy),
+            role = _get_role(role_name, region)
+            if role is None:
+                break
+        else:
+            raise RuntimeError(
+                "We weren't able to connect your account with the Anyscale because we weren't able to find an available IAM Role name in your account. Please reach out to support or your SA for assistance."
             )
-            role = _get_role(ANYSCALE_IAM_ROLE_NAME, region)
 
-        assert role is not None, "Failed to create IAM role!"
+        iam = _resource("iam", region)
+        iam.create_role(
+            RoleName=role_name,
+            AssumeRolePolicyDocument=json.dumps(anyscale_aws_iam_role_policy),
+        )
+        role = _get_role(role_name, region)
 
-        role.attach_policy(PolicyArn=AMAZON_EC2_FULL_ACCESS_POLICY_ARN)
-        role.attach_policy(PolicyArn=AMAZON_IAM_FULL_ACCESS_POLICY_ARN)
+        assert role is not None, "Failed to create IAM role."
 
-        self.log.info(f"Using IAM role {role.arn}")
-
-        created_cloud = self.api_client.create_cloud_api_v2_clouds_post(
-            write_cloud=WriteCloud(
-                provider="AWS", region=region, credentials=role.arn, name=name,
-            )
+        role.Policy(name="Anyscale_IAM_Policy_Steady_State").put(
+            PolicyDocument=json.dumps(ANYSCALE_IAM_PERMISSIONS_EC2_STEADY_STATE)
         )
 
-        # NOTE: If we are modifying an existing Role that does not have External IDs, we
-        # cannot add an ExternalID check to the policy because it could break old clouds.
-        if (
-            role_exists
-            and number_of_external_ids_in_policy(role.assume_role_policy_document) == 0
-        ):
-            return
+        role.Policy(name="Anyscale_IAM_Policy_Initial_Setup").put(
+            PolicyDocument=json.dumps(ANYSCALE_IAM_PERMISSIONS_EC2_INITIAL_RUN)
+        )
+
+        self.log.info(f"Using IAM role {role.arn}")
+        try:
+
+            created_cloud = self.api_client.create_cloud_api_v2_clouds_post(
+                write_cloud=WriteCloud(
+                    provider="AWS", region=region, credentials=role.arn, name=name,
+                )
+            )
+        except ClickException:
+            self.log.info("Create failed, cleaning up IAM role: {}".format(role_name))
+            try:
+                for policy in role.policies.all():
+                    policy.delete()
+                role.delete()
+            except botocore.exceptions.ClientError:
+                self.log.error(
+                    "Failed to clean up IAM role after a failed cloud creation: {}".format(
+                        role_name
+                    )
+                )
+            raise
+        cloud_id = created_cloud.result.id
+
+        iam_client = _client("iam", region)
+        iam_client.update_role(
+            RoleName=role.name,
+            Description="Anyscale access role for cloud {} in region {}".format(
+                cloud_id, created_cloud.result.region
+            ),
+        )
 
         # NOTE: We update this _after_ cloud creation because this External ID MUST
         # come from Anyscale, not the customer. We are using the `cloud_id` as it is unique per cloud.
         # https://docs.aws.amazon.com/IAM/latest/UserGuide/id_roles_create_for-user_externalid.html
         new_policy = _update_external_ids_for_policy(
-            role.assume_role_policy_document, created_cloud.result.id
+            role.assume_role_policy_document, cloud_id
         )
 
         role.AssumeRolePolicy().update(PolicyDocument=json.dumps(new_policy))
@@ -342,110 +350,11 @@ class CloudController(BaseController):
         # Modified permissions from Ray (no EC2FullAccess)
         role.attach_policy(PolicyArn=AMAZON_S3_FULL_ACCESS_POLICY_ARN)
 
-    def setup_aws_k8s_cloud(self, region: str, name: str, yes: bool) -> None:
-        confirm(
-            "\nYou are about to give Anyscale access to EC2, EKS, and IAM "
-            "in your AWS account.\n\nContinue?",
-            yes,
-        )
-
-        # Create cloud in DB.
-        account_id = boto3.client("sts").get_caller_identity()["Account"]
-        cloud_response: CloudResponse = self.api_client.create_cloud_api_v2_clouds_post(
-            write_cloud=WriteCloud(
-                name=name,
-                provider=CloudProviders.AWS,
-                region=region,
-                credentials=account_id,
-                is_k8s=True,
-                is_aioa=False,
-            )
-        )
-        created_cloud: Cloud = cloud_response.result
-
-        # Grant Anyscale access.
-        cloud_credentials = json.loads(created_cloud.credentials)
-        # TODO: this should ideally be a model, but we don't expose this one in the client.
-        if not isinstance(cloud_credentials, dict):
-            raise TypeError("unable to interpret credentials of created cloud")
-        access_role_arn = cloud_credentials.get("customer_cloud_access_role_arn")
-        if not isinstance(access_role_arn, str):
-            raise TypeError(f"invalid access role in created cloud: {access_role_arn}")
-        _, _, access_role_name = access_role_arn.partition("/")
-        if not access_role_name:
-            raise ValueError("no access role name in credentials for created cloud")
-        anyscale_role_arn = cloud_credentials.get("anyscale_cloud_access_role_arn")
-        if not isinstance(anyscale_role_arn, str):
-            raise TypeError(
-                f"invalid Anyscale role in created cloud: {anyscale_role_arn}"
-            )
-        iam = _resource(name="iam", region=region)
-        for _ in range(ROLE_CREATION_RETRIES):
-            try:
-                role = iam.create_role(
-                    RoleName=access_role_name,
-                    AssumeRolePolicyDocument=json.dumps(
-                        {
-                            "Version": "2012-10-17",
-                            "Statement": {
-                                "Sid": "1",
-                                "Effect": "Allow",
-                                "Principal": {"AWS": anyscale_role_arn},
-                                "Action": "sts:AssumeRole",
-                                "Condition": {
-                                    "StringEquals": {"sts:ExternalId": created_cloud.id}
-                                },
-                            },
-                        }
-                    ),
-                )
-            except botocore.exceptions.ClientError:
-                time.sleep(ROLE_CREATION_INTERVAL_SECONDS)
-                continue
-            else:
-                break
-        anyscale_iam_policy = iam.Policy(
-            arn=f"arn:aws:iam::{account_id}:policy/{ANYSCALE_IAM_ACCESS_POLICY_NAME}"
-        )
-        try:
-            anyscale_iam_policy.load()
-        except botocore.exceptions.ClientError as exc:
-            if exc.response.get("Error", {}).get("Code") != "NoSuchEntity":
-                raise
-            anyscale_iam_policy = iam.create_policy(
-                PolicyName="AnyscaleIAMAccess",
-                PolicyDocument=json.dumps(ANYSCALE_IAM_ACCESS_POLICY_DOCUMENT),
-            )
-        eks_full_access_policy = iam.Policy(
-            arn=f"arn:aws:iam::{account_id}:policy/{EKS_FULL_ACCESS_POLICY_NAME}"
-        )
-        try:
-            eks_full_access_policy.load()
-        except botocore.exceptions.ClientError as exc:
-            if exc.response.get("Error", {}).get("Code") != "NoSuchEntity":
-                raise
-            eks_full_access_policy = iam.create_policy(
-                PolicyName="EKSFullAccess",
-                PolicyDocument=json.dumps(EKS_FULL_ACCESS_POLICY_DOCUMENT),
-                Description="This policy gives the role full access to EKS.",
-            )
-        role.attach_policy(PolicyArn=anyscale_iam_policy.arn)
-        role.attach_policy(PolicyArn=eks_full_access_policy.arn)
-        role.attach_policy(PolicyArn=AMAZON_VPC_FULL_ACCESS_POLICY_ARN)
-        role.attach_policy(PolicyArn=AMAZON_EC2_FULL_ACCESS_POLICY_ARN)
-        role.attach_policy(PolicyArn=AMAZON_CLOUDWATCH_FULL_ACCESS_POLICY_ARN)
-        role.attach_policy(PolicyArn=AMAZON_ROUTE53_FULL_ACCESS_POLICY_ARN)
-
-        self.log.info(
-            "Cloud creation in progress. Your cloud should be available in 20-30 minutes."
-        )
-        self.log.info(
-            f"If you want to remove this cloud, run `anyscale cloud delete -n {name}."
-        )
-        self.log.warning(
-            f"If you delete the role {access_role_name} without deleting the cloud, there "
-            "might remain resources running in your account."
-        )
+        for profile in role.instance_profiles.all():
+            if profile.name == role_name:
+                return
+        profile = iam.create_instance_profile(InstanceProfileName=role_name)
+        profile.add_role(RoleName=role_name)
 
     def update_cloud_config(
         self,
