@@ -40,7 +40,7 @@ from anyscale.sdk.anyscale_client.models.create_cluster_compute import (
     CreateClusterCompute,
 )
 from anyscale.shared_anyscale_utils.util import slugify
-from anyscale.shared_anyscale_utils.utils.byod import BYODInfo
+from anyscale.shared_anyscale_utils.utils.byod import BYOD_DISPLAY_PREFIX, BYODInfo
 from anyscale.util import (
     extract_versions_from_image_name,
     get_endpoint,
@@ -144,8 +144,16 @@ class ClusterController(BaseController):
         )
 
         url = get_endpoint(f"/projects/{project_id}/clusters/{cluster.id}")
+        if cluster_env.name.startswith(BYOD_DISPLAY_PREFIX):
+            # Don't include build.revision or build.id for BYOD images
+            cluster_environment_display = f"{cluster_env.name}"
+        else:
+            cluster_environment_display = (
+                f"{cluster_env.name}.{build.revision} (id={build.id})"
+            )
+
         cluster_start_parameters_str = (
-            f"\t\t\tCluster environment: {cluster_env.name}.{build.revision} (id={build.id})\n"
+            f"\t\t\tCluster environment: {cluster_environment_display}\n"
             f"\t\t\tCluster compute: {cluster_compute.name} (id={cluster_compute.id})\n"
             f"\t\t\tProject: {project_id}\n"
             f"\t\t\tCloud: {cloud_name}\n"
@@ -206,6 +214,39 @@ class ClusterController(BaseController):
         url = get_endpoint(f"/projects/{project_id}/clusters/{cluster.id}")
         self.log.info(f"Cluster {cluster_name} is terminating. View progress at {url}")
 
+    def archive(
+        self,
+        cluster_name: Optional[str],
+        cluster_id: Optional[str],
+        project_id: Optional[str],
+        project_name: Optional[str],
+    ) -> None:
+        if cluster_name is not None and cluster_id is not None:
+            raise click.ClickException(
+                "`--name` and `--cluster-id` cannot both be specified. Please only provide one"
+                "of these two arguments."
+            )
+        if cluster_name is None and cluster_id is None:
+            raise click.ClickException(
+                "Please specity one of `--name` or `--cluster-id`."
+            )
+        project_id, cluster_name = self._get_project_id_and_cluster_name(
+            cluster_id, project_id, cluster_name, project_name
+        )
+
+        cluster_list = self.anyscale_api_client.search_clusters(
+            {"project_id": project_id, "name": {"equals": cluster_name}}
+        ).results
+        if len(cluster_list) == 0:
+            raise click.ClickException(
+                f"No cluster {cluster_name} found in project {project_id}."
+            )
+
+        cluster = cluster_list[0]
+
+        self.anyscale_api_client.archive_cluster(cluster.id)
+        self.log.info(f"Cluster {cluster.id} is successfully archived.")
+
     def list(
         self,
         cluster_name: Optional[str],
@@ -213,6 +254,7 @@ class ClusterController(BaseController):
         project_id: Optional[str],
         include_all_projects: bool,
         include_inactive: bool,
+        include_archived: bool,
         max_items: int,
         project_name: Optional[str],
     ) -> None:
@@ -268,6 +310,8 @@ class ClusterController(BaseController):
                 search_clusters_query["project_id"] = project_id
             if not include_inactive:
                 search_clusters_query["state_filter"] = ["Running"]
+            if include_archived:
+                search_clusters_query["archive_status"] = "ALL"
 
             # Page through all clusters in response
             cluster_list_resp = self.api_client.list_decorated_clusters_api_v2_decorated_sessions_get(
