@@ -1,10 +1,13 @@
 from abc import ABC, abstractmethod
 from datetime import datetime
+import json
 import os
 from pathlib import Path
 import time
+import traceback
 from typing import Any, cast, Dict, List, Optional, Tuple, Type, Union
 from urllib.parse import urlparse
+import uuid
 
 import click
 from pydantic import BaseModel, Field, root_validator
@@ -25,6 +28,7 @@ from anyscale.client.openapi_client import (
 from anyscale.cluster_compute import (
     get_cluster_compute_from_name,
     get_default_cluster_compute,
+    register_compute_template,
 )
 from anyscale.cluster_env import (
     get_build_from_cluster_env_identifier,
@@ -42,6 +46,7 @@ from anyscale.shared_anyscale_utils.utils.byod import BYODInfo
 from anyscale.util import (
     extract_versions_from_image_name,
     get_endpoint,
+    is_anyscale_workspace,
     poll,
     PROJECT_NAME_ENV_VAR,
 )
@@ -60,6 +65,7 @@ pending_states = {
     HaJobStates.PENDING,
     HaJobStates.AWAITING_CLUSTER_START,
     HaJobStates.ERRORED,
+    HaJobStates.RESTARTING,
 }
 
 
@@ -251,9 +257,10 @@ class JobConfig(BaseModel):
         None,
         description="The name of the project you want to use. If not specified, and no project is inferred from the directory, no project will be used.",
     )
-    compute_config: Optional[str] = Field(
+    compute_config: Optional[Union[str, Dict[str, Any]]] = Field(
         None,
-        description="The name of the compute configuration that you want to use. This will specify the resources required for your job",
+        description="The name of the compute configuration that you want to use. This will specify the resources required for your job."
+        "This field also accepts a one-off config as a dictionary.",
     )
     cloud: Optional[str] = Field(
         None,
@@ -353,23 +360,23 @@ class JobConfig(BaseModel):
             raise click.ClickException(
                 "Only one of `compute_config_id`, `compute_config`, or `cloud` can be provided in the job config file."
             )
-        if compute_config:
+        if compute_config and isinstance(compute_config, str):
             compute_config_id = get_cluster_compute_from_name(compute_config).id
-            values["compute_config_id"] = compute_config_id
+        elif compute_config and isinstance(compute_config, dict):
+            compute_config_id = register_compute_template(compute_config).id
         elif cloud:
             # Get default cluster compute for the specified cloud.
             compute_config_id = get_default_cluster_compute(cloud, None).id
-            values["compute_config_id"] = compute_config_id
             log.info(
                 f"Using default compute config for specified cloud {cloud}: {compute_config_id}."
             )
         elif not compute_config_id:
             # Get default cluster compute for the default cloud.
             compute_config_id = get_default_cluster_compute(None, None).id
-            values["compute_config_id"] = compute_config_id
             log.info(
                 f"No cloud or compute config specified, using the default: {compute_config_id}."
             )
+        values["compute_config_id"] = compute_config_id
 
         return values
 
@@ -513,26 +520,61 @@ class JobController(BaseController):
         self.log.open_block("Output")
 
     def submit(
-        self, job_config_file: str, name: Optional[str], description: Optional[str]
+        self,
+        job_config_file: str,
+        name: Optional[str] = None,
+        description: Optional[str] = None,
+        is_entrypoint_cmd: Optional[bool] = False,
+        entrypoint: Optional[List[str]] = None,
     ) -> str:
-        job_config = self._read_job_config(job_config_file)
-        project_id = job_config.project_id
 
-        # If project id is not specified, try to infer it
-        if not project_id:
-            # Check directory of .anyscale.yaml to decide whether to use default project.
-            root_dir = find_project_root(os.getcwd())
-            if root_dir is not None:
-                project_definition = ProjectDefinition(root_dir)
-                project_id = get_project_id(project_definition.root)
-            else:
-                default_project = self.anyscale_api_client.get_default_project().result
-                project_id = default_project.id
-                self.log.info("No project specified. Continuing without a project.")
-        if job_config.runtime_env:
-            job_config.runtime_env = upload_and_rewrite_working_dir(
-                job_config.runtime_env, self.log
+        entrypoint = entrypoint or []
+        if is_anyscale_workspace() and is_entrypoint_cmd:
+            entrypoint = [job_config_file, *entrypoint]
+            id = self.submit_with_entrypoint(entrypoint, name, description)
+        elif len(entrypoint) == 0:
+            # Assume that job_config_file is a file and submit it.
+            id = self.submit_from_file(
+                job_config_file, name=name, description=description
             )
+        elif len(entrypoint) != 0:
+            msg = (
+                "Within an Anyscale Workspace, `anyscale job submit` takes either a file, or a command. To submit a command, use `anyscale job submit -- my command`."
+                if is_anyscale_workspace()
+                else "`anyscale job submit` takes one argument, a YAML file configuration. Please use `anyscale job submit my_file`."
+            )
+            raise click.ClickException(msg)
+        return id
+
+    def submit_with_entrypoint(
+        self, entrypoint: List[str], name: Optional[str], description: Optional[str]
+    ):
+        config_dict = {
+            "entrypoint": " ".join(entrypoint),
+            "name": name,
+            "description": description,
+        }
+        job_config = self._populate_job_config(config_dict)
+        return self.submit_from_config(job_config)
+
+    def submit_from_file(
+        self, job_config_file: str, name: Optional[str], description: Optional[str],
+    ) -> str:
+
+        config_dict = self._load_config_dict_from_file(job_config_file)
+        job_config = self._populate_job_config(config_dict)
+        if name:
+            job_config.name = name
+
+        if description:
+            job_config.description = description
+
+        return self.submit_from_config(job_config)
+
+    def submit_from_config(self, job_config: JobConfig):
+        # If project id is not specified, try to infer it
+        project_id = self._infer_project_id(job_config)
+        self._override_runtime_env(job_config)
 
         config_object = ProductionJobConfig(
             entrypoint=job_config.entrypoint,
@@ -544,12 +586,8 @@ class JobController(BaseController):
 
         job = self.api_client.create_job_api_v2_decorated_ha_jobs_create_post(
             CreateProductionJob(
-                name=name
-                or job_config.name
-                or "cli-job-{}".format(datetime.now().isoformat()),
-                description=description
-                or job_config.description
-                or "Job submitted from CLI",
+                name=job_config.name or "cli-job-{}".format(datetime.now().isoformat()),
+                description=job_config.description or "Job submitted from CLI",
                 project_id=project_id,
                 config=config_object,
             )
@@ -567,12 +605,69 @@ class JobController(BaseController):
         self.log.info(f'View the job in the UI at {get_endpoint(f"/jobs/{job.id}")}.')
         return job.id
 
-    def _read_job_config(self, job_config_file: str) -> JobConfig:
+    def _override_runtime_env(self, job_config: JobConfig) -> JobConfig:
+        if is_anyscale_workspace():
+            import anyscale
+
+            job_config.runtime_env = anyscale.snapshot_util.env_hook(
+                job_config.runtime_env
+            )
+            # Snapshot the working directory to EFS so the job we submit can read it from there
+            job_config.runtime_env["working_dir"] = (
+                "file://" + job_config.runtime_env["working_dir"]
+            )
+            fake_job_id = uuid.uuid4().hex
+            job_config.runtime_env = anyscale.snapshot_util.checkpoint_job(
+                fake_job_id, job_config.runtime_env
+            )
+            job_config.runtime_env["working_dir"] = (
+                "file://" + job_config.runtime_env["working_dir"]
+            )
+        elif job_config.runtime_env:
+            job_config.runtime_env = upload_and_rewrite_working_dir(
+                job_config.runtime_env, self.log
+            )
+        return job_config
+
+    def _infer_project_id(self, job_config: JobConfig) -> str:
+        project_id = job_config.project_id
+        if not project_id:
+            # Check directory of .anyscale.yaml to decide whether to use default project.
+            root_dir = find_project_root(os.getcwd())
+            if root_dir is not None:
+                project_definition = ProjectDefinition(root_dir)
+                project_id = get_project_id(project_definition.root)
+            else:
+                default_project = self.anyscale_api_client.get_default_project().result
+                project_id = default_project.id
+                self.log.info("No project specified. Continuing without a project.")
+        return cast(str, project_id)
+
+    def _load_config_dict_from_file(self, job_config_file: str) -> Dict[str, Any]:
         if not os.path.exists(job_config_file):
             raise click.ClickException(f"Config file {job_config_file} not found.")
 
         with open(job_config_file, "r") as f:
             config_dict = yaml.safe_load(f)
+        return config_dict
+
+    def _populate_job_config(self, config_dict: Dict[str, Any]) -> JobConfig:
+
+        if "ANYSCALE_EXPERIMENTAL_WORKSPACE_ID" in os.environ:
+            if "ANYSCALE_SESSION_ID" in os.environ:
+                cluster = self.anyscale_api_client.get_cluster(
+                    os.environ["ANYSCALE_SESSION_ID"]
+                ).result
+                # If the job configs are not specified, infer them from the workspace:
+                if "build_id" not in config_dict and "cluster_env" not in config_dict:
+                    config_dict["build_id"] = cluster.cluster_environment_build_id
+                if "project_id" not in config_dict:
+                    config_dict["project_id"] = cluster.project_id
+                if (
+                    "compute_config" not in config_dict
+                    and "compute_config_id" not in config_dict
+                ):
+                    config_dict["compute_config_id"] = cluster.cluster_compute_id
 
         job_config = JobConfig.parse_obj(config_dict)
         return job_config
@@ -887,3 +982,25 @@ class JobController(BaseController):
                 # before fetching more logs
                 if jr.job_state in pending_states:
                     self._wait_for_job_running(job_id)
+
+    def retrieve_output(
+        self, job_name: Optional[str] = None, job_id: Optional[str] = None,
+    ) -> None:
+        if not job_id:
+            job = self._resolve_job_object(job_id, job_name)
+            job_id = job.id
+
+        try:
+            output = self.api_client.find_structured_job_output_api_v2_structured_outputs_ha_job_output_ha_job_id_get(
+                ha_job_id=job_id
+            )
+            self.log.log(json.dumps(output.result.output, indent=2))
+        except Exception as e:
+            traceback.print_exc()
+            try:
+                j = json.loads(e.body)  # type: ignore
+                detail = j.get("error", {}).get("detail")
+                self.log.error(detail)
+            except Exception:
+                # Swallow if pretty print logic fails
+                pass
