@@ -8,11 +8,10 @@ from typing import Any, Dict, List, Optional, Tuple
 
 import tabulate
 
-from anyscale.api import get_api_client
-from anyscale.cli_logger import _CliLogger
-from anyscale.client.openapi_client.api.default_api import DefaultApi
+from anyscale.cli_logger import BlockLogger
 from anyscale.cloud import get_cloud_json_from_id
 from anyscale.cluster_config import get_cluster_config
+from anyscale.controllers.base_controller import BaseController
 from anyscale.formatters import clouds_formatter
 from anyscale.project import (
     get_proj_name_from_id,
@@ -24,12 +23,13 @@ from anyscale.project import (
 from anyscale.util import get_endpoint, humanize_timestamp
 
 
-class ListController(object):
-    def __init__(self, api_client: DefaultApi = None, log: _CliLogger = _CliLogger()):
-        if api_client is None:
-            api_client = get_api_client()
-        self.api_client = api_client
+class ListController(BaseController):
+    def __init__(
+        self, log: BlockLogger = BlockLogger(), initialize_auth_api_client: bool = True
+    ):
+        super().__init__(initialize_auth_api_client=initialize_auth_api_client)
         self.log = log
+        self.log.open_block("Output")
 
     def list_clouds(self, json_format: bool) -> str:
         clouds = self.api_client.list_clouds_api_v2_clouds_get().results
