@@ -49,11 +49,7 @@ class ServiceController(BaseController):
         )
 
     def deploy(
-        self,
-        service_config_file: str,
-        name: Optional[str],
-        description: Optional[str],
-        do_apply: Optional[bool] = False,
+        self, service_config_file: str, name: Optional[str], description: Optional[str],
     ) -> None:
         if not os.path.exists(service_config_file):
             raise click.ClickException(f"Config file {service_config_file} not found.")
@@ -88,46 +84,21 @@ class ServiceController(BaseController):
             compute_config_id=service_config.compute_config_id,
             max_retries=service_config.max_retries,
         )
-        if not do_apply:
-            service = self.api_client.create_service_api_v2_decorated_ha_jobs_create_service_post(
-                CreateProductionService(
-                    name=name
-                    or service_config.name
-                    or "cli-job-{}".format(datetime.now().isoformat()),
-                    description=description
-                    or service_config.description
-                    or "Service deployed from CLI",
-                    project_id=project_id,
-                    config=config_object,
-                    healthcheck_url=service_config.healthcheck_url,
-                    access=service_config.access,
-                )
-            ).result
-        else:
-            flag_info = self.api_client.check_is_feature_flag_on_api_v2_userinfo_check_is_feature_flag_on_get(
-                flag_key="enable_reconcile_service_update",
-            ).result
 
-            if not flag_info.is_on:
-                self.log.info(
-                    "Service failed to apply. Updating service is in alpha and is not enabled for your account. Please contact security@anyscale.com if you would like to try out this feature."
-                )
-                return
-
-            service = self.api_client.apply_service_api_v2_decorated_ha_jobs_apply_service_put(
-                CreateProductionService(
-                    name=name
-                    or service_config.name
-                    or "cli-job-{}".format(datetime.now().isoformat()),
-                    description=description
-                    or service_config.description
-                    or "Service updated from CLI",
-                    project_id=project_id,
-                    config=config_object,
-                    healthcheck_url=service_config.healthcheck_url,
-                    access=service_config.access,
-                )
-            ).result
+        service = self.api_client.apply_service_api_v2_decorated_ha_jobs_apply_service_put(
+            CreateProductionService(
+                name=name
+                or service_config.name
+                or "cli-job-{}".format(datetime.now().isoformat()),
+                description=description
+                or service_config.description
+                or "Service updated from CLI",
+                project_id=project_id,
+                config=config_object,
+                healthcheck_url=service_config.healthcheck_url,
+                access=service_config.access,
+            )
+        ).result
 
         self.log.info(
             f"Service {service.id} has been deployed. Current state of service: {service.state.current_state}."
