@@ -2,9 +2,10 @@ from datetime import datetime
 import json
 import os
 from os import path
+import shlex
 import subprocess
 import sys
-from typing import Any, Dict, List, Optional, Tuple, Union
+from typing import Any, Dict, List, Optional, Sequence, Union
 
 import click
 import yaml
@@ -28,6 +29,7 @@ from anyscale.cluster_config import (  # pylint:disable=private-import
 )
 from anyscale.controllers.base_controller import BaseController
 from anyscale.project import (
+    get_and_validate_project_id,
     get_project_id,
     get_project_session,
     get_project_sessions,
@@ -79,7 +81,6 @@ class SessionController(BaseController):
         delete: bool,
         workers_only: bool,
         keep_min_workers: bool,
-        skip_snapshot: bool = False,
     ) -> None:
         project_definition = load_project_or_throw()
         project_id = get_project_id(project_definition.root)
@@ -104,7 +105,6 @@ class SessionController(BaseController):
                     workers_only=workers_only,
                     keep_min_workers=keep_min_workers,
                     delete=delete,
-                    take_snapshot=not skip_snapshot,
                 ),
             )
 
@@ -371,10 +371,12 @@ class SessionController(BaseController):
     def ssh(
         self,
         session_name: str,
-        ssh_option: Tuple[str],
+        ssh_option: Sequence[str],
         worker_node_id: Optional[str],
         worker_node_ip: Optional[str],
         force_head_node: bool,
+        project_id: Optional[str],
+        cmd: Optional[str] = None,
     ) -> None:
 
         config_path = "/home/ray/ray_bootstrap_config.yaml"
@@ -438,13 +440,19 @@ class SessionController(BaseController):
             )
         else:
             # On a laptop
-
-            project_definition = load_project_or_throw()
-            project_id = get_project_id(project_definition.root)
+            project_id = get_and_validate_project_id(
+                project_id=project_id,
+                project_name=None,
+                api_client=self.api_client,
+                anyscale_api_client=self.anyscale_api_client,
+            )
             session = get_project_session(project_id, session_name, self.api_client)
 
             cluster_config = get_cluster_config(
-                session_name, self.api_client, disable_project_sync=True
+                session_name,
+                self.api_client,
+                disable_project_sync=True,
+                project_id=project_id,
             )
 
             head_ip = self.api_client.get_session_head_ip_api_v2_sessions_session_id_head_ip_get(
@@ -461,12 +469,14 @@ class SessionController(BaseController):
                 + ["-tt", "-i", key_path]
                 + ["{}@{}".format(ssh_user, head_ip)]
             )
+            if cmd:
+                command = shlex.quote(cmd)
+            else:
+                command = shlex.quote("which bash && bash || sh")
 
             if ssh_to_head:
                 ssh_command = base_ssh_command + (
-                    [
-                        f"docker exec -it {container_name} sh -c 'which bash && bash || sh'"
-                    ]
+                    [f"docker exec -it {container_name} sh -c {command}"]
                     if container_name
                     else []
                 )
@@ -498,15 +508,16 @@ class SessionController(BaseController):
         source: Optional[str] = None,
         target: Optional[str] = None,
         config: Optional[str] = None,
+        rsync_exclude_override: Optional[List[str]] = None,
     ) -> None:
-        message = "Warning: `anyscale pull` has been deprecated and will be removed in the future. "
-        self.log.warning(message)
         project_definition = load_project_or_throw()
 
         try:
             self.log.info("Collecting files from remote.")
             project_id = get_project_id(project_definition.root)
             cluster_config = get_cluster_config(session_name, self.api_client)
+            if rsync_exclude_override is not None:
+                cluster_config["rsync_exclude"] = rsync_exclude_override
             directory_name = get_working_dir(
                 cluster_config, project_id, self.api_client
             )
@@ -558,7 +569,7 @@ class SessionController(BaseController):
         target: Optional[str],
         config: Optional[str],
         all_nodes: bool,
-        no_warning: bool = False,
+        rsync_exclude_override: Optional[List[str]] = None,
     ) -> None:
         if all_nodes:
             raise click.ClickException(
@@ -567,13 +578,6 @@ class SessionController(BaseController):
                 "added during autoscaling. Going forward, Anyscale will only support syncing "
                 "working directory files to the head and workers."
             )
-        if not no_warning:
-            message = (
-                "Warning: `anyscale push` has been deprecated and will be removed in the future. "
-                "Please sync files to the cluster using the `working_dir` in Ray client. Please "
-                "contact the Anyscale team if you are having any issues with this for your use case."
-            )
-            self.log.warning(message)
 
         project_definition = load_project_or_throw()
         project_id = get_project_id(project_definition.root)
@@ -581,6 +585,8 @@ class SessionController(BaseController):
         session_name = session.name
 
         cluster_config = get_cluster_config(session_name, self.api_client)
+        if rsync_exclude_override is not None:
+            cluster_config["rsync_exclude"] = rsync_exclude_override
         target = canonicalize_remote_location(cluster_config, target, project_id)
 
         aws_credentials = get_credentials_as_env_vars_from_cluster_config(
