@@ -141,12 +141,21 @@ def _get_project_sessions(project_id: str, session_name: Optional[str]) -> Any:
 
 
 def get_project_session(
-    project_id: str, session_name: Optional[str], api_client: DefaultApi = None
+    project_id: str,
+    session_name: Optional[str],
+    api_client: DefaultApi = None,
+    is_workspace=False,
 ) -> Any:
     if api_client is None:
         return _get_project_session(project_id, session_name)
 
     sessions = get_project_sessions(project_id, session_name, api_client)
+    if is_workspace:
+        # TODO(https://github.com/anyscale/product/issues/11585): We need a more robust way to find workspaces.
+        sessions = [
+            session for session in sessions if session.name.startswith("workspace-")
+        ]
+
     if len(sessions) > 1:
         raise ClickException(
             "Multiple active clusters: {}\n"
@@ -228,7 +237,7 @@ def get_proj_id_from_name(
     return str(selected_project.id)
 
 
-def _write_project_file_to_disk(project_id: str, directory: str) -> None:
+def write_project_file_to_disk(project_id: str, directory: str) -> None:
     with open(os.path.join(directory, ANYSCALE_PROJECT_FILE), "w") as f:
         f.write("{}".format("project_id: {}".format(project_id)))
 
