@@ -8,6 +8,7 @@ import click
 
 from anyscale.cli_logger import BlockLogger
 from anyscale.commands.anyscale_api.api_commands import anyscale_api
+from anyscale.commands.auth_commands import auth_cli
 from anyscale.commands.cloud_commands import cloud_cli
 from anyscale.commands.cluster_commands import cluster_cli
 from anyscale.commands.cluster_compute_commands import cluster_compute_cli
@@ -34,7 +35,6 @@ from anyscale.commands.session_commands import (
 from anyscale.commands.session_commands_hidden import session_cli
 from anyscale.commands.workspace_commands import workspace_cli
 import anyscale.conf
-from anyscale.util import init_sentry
 
 
 logger = logging.getLogger(__file__)
@@ -82,12 +82,6 @@ class AliasedGroup(click.Group):
 def cli(ctx: Any, version_flag: bool, show_json: bool) -> None:
     # Use anyscale vendored Ray for the CLI:
     sys.path.insert(0, anyscale.ANYSCALE_RAY_DIR)
-    if (
-        (ctx.invoked_subcommand not in {"help", "version"})
-        and ("--help" not in sys.argv)
-        and ("-h" not in sys.argv)
-    ):
-        init_sentry(ctx.invoked_subcommand)
 
     if version_flag:
         ctx.invoke(version_cli, show_json=show_json)
@@ -101,7 +95,7 @@ def version_cli(show_json: bool) -> None:
     if show_json:
         print(json.dumps({"version": anyscale.__version__}))
     else:
-        log.info(anyscale.__version__)
+        print(anyscale.__version__)
 
 
 @cli.command(
@@ -124,6 +118,7 @@ cli.add_command(job_cli)
 cli.add_command(service_cli)
 cli.add_command(cluster_cli)
 cli.add_command(workspace_cli)
+cli.add_command(auth_cli)
 
 cli.add_command(anyscale_init)
 cli.add_command(anyscale_up)
