@@ -10,13 +10,27 @@ from typing import Any, Dict, Optional
 
 
 logger = logging.getLogger(__name__)
-logging.basicConfig(level=logging.INFO)
+logging.basicConfig(level=os.environ.get("ANYSCALE_LOGLEVEL", "WARN"))
 
 # Built-in configs.
 WORKING_DIR = os.environ.get("ANYSCALE_WORKING_DIR", "/home/ray")
+# These files are saved per workspace.
+CONFIGS_TO_SAVE = [
+    ".bash_history",
+]
+# These files are saved per user.
+CONFIGS_TO_REPLICATE = [
+    ".workspacerc",
+    ".gitconfig",
+    ".vimrc",
+]
 
 # Experimental configs propagated from the cluster config service.
 EFS_IP = os.environ.get("ANYSCALE_EXPERIMENTAL_EFS_IP", "")
+# Override with container-defined IP.
+CUSTOM_EFS_IP = os.environ.get("CUSTOM_EFS_IP", "")
+if CUSTOM_EFS_IP:
+    EFS_IP = CUSTOM_EFS_IP
 WORKSPACE_ID = os.environ.get("ANYSCALE_EXPERIMENTAL_WORKSPACE_ID", "")
 USERNAME = os.environ.get("ANYSCALE_EXPERIMENTAL_USERNAME", "unknown_user")
 BASE_SNAPSHOT = os.environ.get("ANYSCALE_EXPERIMENTAL_BASE_SNAPSHOT") or None
@@ -87,18 +101,12 @@ def create_snapshot_zip(directory: str, auto: bool) -> str:
 
     start = time.time()
     orig = os.path.abspath(os.curdir)
-    prefix = "snapshot_{}_".format(datetime.datetime.now().isoformat())
+    prefix = "snapshot_{}_".format(datetime.datetime.utcnow().isoformat())
     if auto:
         prefix += "auto_"
     target = tempfile.mktemp(suffix=".zip", prefix=prefix)
     try:
         os.chdir(directory)
-        for child in os.listdir("."):
-            if os.path.exists(os.path.join(child, ".git")):
-                raise ValueError(
-                    f"Git repo detected in sub-directory {child}. Please ensure that "
-                    "your git repo is cloned in the top-level workspace directory."
-                )
         if os.path.exists(".git"):
             subprocess.check_call(  # noqa
                 "(git ls-files -co --exclude-standard || true; find .git || true) | "
@@ -106,6 +114,13 @@ def create_snapshot_zip(directory: str, auto: bool) -> str:
                 shell=True,
             )
         else:
+            for child in os.listdir("."):
+                if os.path.exists(os.path.join(child, ".git")):
+                    raise ValueError(
+                        f"Git repo detected in sub-directory {child}. Please ensure "
+                        "that your git repo is cloned in the top-level workspace "
+                        f"directory with 'git clone <repo> .' at {directory}."
+                    )
             subprocess.check_call(  # noqa
                 f"find . | zip --symlinks -@ -0 -q {target}", shell=True,
             )
@@ -202,10 +217,10 @@ def do_snapshot(auto: bool = False):
     shutil.move(
         zip + ".md5", os.path.join(snapshot_dir, os.path.basename(zip) + ".md5")
     )
-    shutil.copy(
-        os.path.expanduser("~/.bash_history"),
-        os.path.join(workspace_dir, ".bash_history"),
-    )
+    for config in CONFIGS_TO_SAVE:
+        shutil.copy(
+            os.path.join("/home/ray", config), os.path.join(workspace_dir, config),
+        )
     if AUTOGC:
         gc_snapshots()
 
@@ -309,9 +324,10 @@ def restore_latest():
         return
     workspace_dir = os.path.join(EFS_WORKSPACE_DIR, WORKSPACE_ID)
     unpack_snapshot_zip(latest, WORKING_DIR)
-    hist = os.path.join(workspace_dir, ".bash_history")
-    if os.path.exists(hist):
-        shutil.copy(hist, os.path.expanduser("~/.bash_history"))
+    for config in CONFIGS_TO_SAVE:
+        saved = os.path.join(workspace_dir, config)
+        if os.path.exists(saved):
+            shutil.copy(saved, os.path.join("/home/ray", config))
 
 
 def checkpoint_job(job_id, runtime_env: Dict[str, Any]) -> Dict[str, Any]:
@@ -364,7 +380,7 @@ def setup_ml_dev(runtime_env):
     # TODO(ekl) keep this in sync with setup-dev.py
     LIB_DIRS = [
         "rllib",
-        "ml",
+        "air",
         "tune",
         "serve",
         "train",
@@ -386,15 +402,17 @@ def setup_ml_dev(runtime_env):
         if os.path.isdir(src):
             shutil.rmtree(dst)
             shutil.copytree(os.path.join(local_ray_module, lib_dir), dst)
-        else:
+        elif os.path.exists(src):
             shutil.copy(src, dst)
+        else:
+            logger.info(f"Did not find {src}")
     if "py_modules" not in runtime_env:
         runtime_env["py_modules"] = []
     runtime_env["py_modules"].append(tmp_module)
     return runtime_env
 
 
-def env_hook(runtime_env):
+def env_hook(runtime_env) -> Dict[str, Any]:
     """Env hook for including the working dir in the runtime_env by default.
 
     This should be set as `RAY_RUNTIME_ENV_HOOK=anyscale.snapshot_util.env_hook`.
@@ -403,12 +421,10 @@ def env_hook(runtime_env):
         return checkpoint_job(os.environ["ANYSCALE_EXPERIMENTAL_JOB_ID"], runtime_env)
     if not runtime_env:
         runtime_env = {}
-    if not runtime_env.get("working_dir"):
-        runtime_env["working_dir"] = WORKING_DIR
-    if not runtime_env["working_dir"].endswith(".zip"):
-        workspace = runtime_env["working_dir"]
-        optimize_git_repo(workspace, EFS_OBJECTS_DIR)
-        zipfile = get_or_create_snapshot_zip(workspace, auto=False)
+    # Only fill in the working_dir if it's non-empty (to avoid empty zip errors).
+    if not runtime_env.get("working_dir") and os.listdir(WORKING_DIR):
+        optimize_git_repo(WORKING_DIR, EFS_OBJECTS_DIR)
+        zipfile = get_or_create_snapshot_zip(WORKING_DIR, auto=False)
         # Move the zip file to a consistent path so that we don't leak zip files as
         # jobs are run over time. This isn't thread safe: we assume one job at a time.
         # Note that the zip file isn't needed after the job starts successfully.
@@ -418,10 +434,29 @@ def env_hook(runtime_env):
         runtime_env["working_dir"] = final_path
     if RAY_ML_DEV:
         runtime_env = setup_ml_dev(runtime_env)
+    env_vars = runtime_env.get("env_vars", {})
+    env_vars.update(_load_env_vars())
+    # This if condition is a workaround for
+    # https://github.com/anyscale/product/issues/11679
+    if env_vars:
+        runtime_env["env_vars"] = env_vars
     logger.info("Updated runtime env to {}".format(runtime_env))
     return runtime_env
 
 
+def job_hook(**kwargs):
+    """Job hook to tell users to use normal commands or anyscale job submit.
+
+    This should be set as `RAY_JOB_SUBMIT_HOOK=anyscale.snapshot_util.job_hook`.
+    """
+    cmd = " ".join(kwargs["entrypoint"])
+    raise ValueError(
+        f"`ray job submit` is not needed within a workspace. Run `{cmd}` "
+        f"directly to execute the job in the current cluster. To run on a new "
+        f"cluster, use `anyscale job submit -- {cmd}`."
+    )
+
+
 def setup_credentials():
     """Command to create SSH credentials for the workspace.
 
@@ -430,6 +465,7 @@ def setup_credentials():
     """
     private_key = os.path.join(EFS_CREDS_DIR, USERNAME, "id_rsa")
     public_key = os.path.join(EFS_CREDS_DIR, USERNAME, "id_rsa.pub")
+    os.path.join(EFS_CREDS_DIR, USERNAME, "env_vars.json")
     os.makedirs("/home/ray/.ssh", exist_ok=True)
     if os.path.exists(private_key):
         # Copy down from EFS.
@@ -444,6 +480,52 @@ def setup_credentials():
         shutil.copy("/home/ray/.ssh/id_rsa", private_key)
         shutil.copy("/home/ray/.ssh/id_rsa.pub", public_key)
 
+    # Also put stored user env vars in the bashrc.
+    env_vars = _load_env_vars()
+    with open("/home/ray/.bashrc", "a") as bashrc:
+        bashrc.write("\n")
+        for key, value in env_vars.items():
+            bashrc.write(f"export {key}='{value}'\n")
+
+
+def _load_env_vars():
+    env_store = os.path.join(EFS_CREDS_DIR, USERNAME, "env_vars.json")
+    env_vars = {}
+    if os.path.exists(env_store):
+        try:
+            with open(env_store, "r") as f:
+                env_vars = json.loads(f.read())
+        except Exception:
+            logger.exception("Error parsing env vars")
+    return env_vars
+
+
+def _save_env_vars(env_vars: dict):
+    env_store = os.path.join(EFS_CREDS_DIR, USERNAME, "env_vars.json")
+    with open(env_store, "w") as f:
+        f.write(json.dumps(env_vars))
+    print(f"Stored keys: {list(env_vars)}")
+
+
+def get_env_var(key: str):
+    env_vars = _load_env_vars()
+    if key not in env_vars:
+        raise KeyError("No value was put for", key)
+    print(f"{key}={env_vars[key]}")
+
+
+def del_env_var(key: str):
+    env_vars = _load_env_vars()
+    if key in env_vars:
+        del env_vars[key]
+    _save_env_vars(env_vars)
+
+
+def put_env_var(key: str, value: str) -> None:
+    env_vars = _load_env_vars()
+    env_vars[key] = value
+    _save_env_vars(env_vars)
+
 
 def setup_nfs():
     """Setup EFS mounts in the container."""
@@ -455,12 +537,17 @@ def setup_nfs():
         "sudo mount -t nfs4 -o nfsvers=4.1,rsize=1048576,wsize=1048576,hard,"
         f"timeo=600,retrans=2,noresvport {EFS_IP}:/ /efs",
         "sudo mkdir -p /efs",
+        "sudo chown ray /efs",
         f"mkdir -p /efs/workspaces/{WORKSPACE_ID}/cluster_storage",
         f"sudo ln -sf /efs/workspaces/{WORKSPACE_ID}/cluster_storage "
         "/mnt/cluster_storage",
+        f"mkdir -p /efs/users/{USERNAME}",
+        f"sudo ln -sf /efs/users/{USERNAME} /mnt/user_storage",
         "mkdir -p /efs/shared_storage",
         "sudo ln -sf /efs/shared_storage /mnt/shared_storage",
     ]
+    for config in CONFIGS_TO_REPLICATE:
+        COMMANDS.append(f"ln -sf /mnt/user_storage/{config} /home/ray/{config}")
     for cmd in COMMANDS:
         try:
             subprocess.check_call(cmd, shell=True)  # noqa
@@ -512,17 +599,38 @@ def autosnapshot_loop():
         do_snapshot(auto=True)
 
 
+def post_build():
+    CMDS = [
+        "pip install -U https://s3-us-west-2.amazonaws.com/ray-wheels/latest/ray-3.0.0.dev0-cp38-cp38-manylinux2014_x86_64.whl",
+        # TODO: remove this after next image release.
+        "echo 'PROMPT_COMMAND=\"history -a\"' >> /home/ray/.bashrc",
+        "echo '[ -e ~/.workspacerc ] && source ~/.workspacerc' >> /home/ray/.bashrc",
+        "echo 'export PATH=/mnt/cluster_storage/pypi/bin:$PATH' >> /home/ray/.bashrc",
+    ]
+    for cmd in CMDS:
+        print("Executing", cmd)
+        subprocess.check_call(cmd, shell=True)  # noqa
+
+
 if __name__ == "__main__":
     import sys
 
     if sys.argv[1] == "snapshot":
         do_snapshot()
+    elif sys.argv[1] == "post_build":
+        post_build()
     elif sys.argv[1] == "autosnapshot":
         autosnapshot_loop()
     elif sys.argv[1] == "restore":
         restore_latest()
     elif sys.argv[1] == "gc":
         gc_snapshots()
+    elif sys.argv[1] == "put_env":
+        put_env_var(sys.argv[2], sys.argv[3])
+    elif sys.argv[1] == "get_env":
+        get_env_var(sys.argv[2])
+    elif sys.argv[1] == "del_env":
+        del_env_var(sys.argv[2])
     elif sys.argv[1] == "setup_credentials":
         setup_credentials()
     elif sys.argv[1] == "setup_container":
