@@ -1,5 +1,5 @@
 from typing import Any, Dict, Iterator, List, Optional, Tuple
-from unittest.mock import Mock, patch
+from unittest.mock import ANY, Mock, patch
 
 from click import ClickException
 import pytest
@@ -67,17 +67,35 @@ def mock_role(document: Optional[Dict[str, Any]] = None) -> Mock:
     mock_role.arn = "ARN"
     mock_role.attach_policy = Mock()
     mock_role.assume_role_policy_document = document
+    mock_role.instance_profiles.all = Mock(return_value=[])
 
     return mock_role
 
 
+def mock_role_with_external_id() -> Mock:
+    return mock_role(
+        {
+            "Version": "2012-10-17",
+            "Statement": [
+                {
+                    "Sid": "1",
+                    "Effect": "Allow",
+                    "Principal": {"AWS": ["ARN"]},
+                    "Action": "sts:AssumeRole",
+                    "Condition": {"StringEquals": {"sts:ExternalId": "extid"}},
+                }
+            ],
+        }
+    )
+
+
 def test_setup_cloud_aws() -> None:
     with patch.object(
         CloudController, "setup_aws", return_value=None
     ) as mock_setup_aws:
         cloud_controller = CloudController()
         cloud_controller.setup_cloud(
-            is_k8s=False, provider="aws", region=None, name="test-aws", yes=False,
+            provider="aws", region=None, name="test-aws", yes=False,
         )
 
         mock_setup_aws.assert_called_once_with(
@@ -85,20 +103,6 @@ def test_setup_cloud_aws() -> None:
         )
 
 
-def test_setup_cloud_aws_k8s() -> None:
-    with patch.object(
-        CloudController, "setup_aws_k8s_cloud", return_value=None
-    ) as mock_setup_aws_k8s_cloud:
-        cloud_controller = CloudController()
-        cloud_controller.setup_cloud(
-            is_k8s=True, provider="aws", region=None, name="test-aws", yes=False,
-        )
-
-        mock_setup_aws_k8s_cloud.assert_called_once_with(
-            region="us-west-2", name="test-aws", yes=False
-        )
-
-
 def test_setup_cloud_gcp() -> None:
     mock_launch_gcp_cloud_setup = Mock(return_value=None)
     with patch.multiple(
@@ -107,7 +111,7 @@ def test_setup_cloud_gcp() -> None:
     ):
         cloud_controller = CloudController()
         cloud_controller.setup_cloud(
-            is_k8s=True, provider="gcp", region=None, name="test-gcp", yes=True,
+            provider="gcp", region=None, name="test-gcp", yes=True,
         )
 
         mock_launch_gcp_cloud_setup.assert_called_once_with(
@@ -122,12 +126,7 @@ def test_setup_cloud_gcp() -> None:
         mock_launch_gcp_cloud_setup.reset_mock()
 
         cloud_controller.setup_cloud(
-            is_k8s=True,
-            provider="gcp",
-            region=None,
-            name="test-gcp",
-            yes=True,
-            folder_id=1234,
+            provider="gcp", region=None, name="test-gcp", yes=True, folder_id=1234,
         )
 
         mock_launch_gcp_cloud_setup.assert_called_once_with(
@@ -165,7 +164,6 @@ def test_setup_cloud_gcp_vpc_peering(
         if vpc_peering_target_project_id is None or vpc_peering_target_vpc_id is None:
             with pytest.raises(ClickException):
                 cloud_controller.setup_cloud(
-                    is_k8s=True,
                     provider="gcp",
                     region=None,
                     name="test-gcp",
@@ -176,7 +174,6 @@ def test_setup_cloud_gcp_vpc_peering(
                 )
         else:
             cloud_controller.setup_cloud(
-                is_k8s=True,
                 provider="gcp",
                 region=None,
                 name="test-gcp",
@@ -201,7 +198,6 @@ def test_setup_cloud_gcp_vpc_peering(
         mock_launch_gcp_cloud_setup.reset_mock()
 
         cloud_controller.setup_cloud(
-            is_k8s=True,
             provider="gcp",
             region=None,
             name="test-gcp",
@@ -256,7 +252,6 @@ def test_setup_cloud_gcp_vpc_peering_validation(
 
         with pytest.raises(ClickException) as e:
             cloud_controller.setup_cloud(
-                is_k8s=True,
                 provider="gcp",
                 region=None,
                 name="test-gcp",
@@ -278,18 +273,16 @@ def test_setup_cloud_gcp_bad_region() -> None:
         # NOTE: GCP regions are [cont]-[local][number], not [cont]-[local]-[number]
         with pytest.raises(ClickException):
             cloud_controller.setup_cloud(
-                is_k8s=True, provider="gcp", region="us-west-2", name="test-gcp",
+                provider="gcp", region="us-west-2", name="test-gcp",
             )
 
         mock_confirm.assert_called()
 
 
-@pytest.mark.parametrize("is_k8s", [True, False])
-def test_setup_cloud_invalid_provider(is_k8s: bool) -> None:
+def test_setup_cloud_invalid_provider() -> None:
     cloud_controller = CloudController()
     with pytest.raises(ClickException):
         cloud_controller.setup_cloud(
-            is_k8s=is_k8s,
             provider="azure",
             region="azure-west-1",
             name="invalid cloud provider",
@@ -340,31 +333,28 @@ def test_missing_name_and_id() -> None:
         cloud_controller.get_cloud_config(None, None)
 
 
-def test_setup_cross_region(cloud_test_data: Cloud) -> None:
+@pytest.mark.parametrize("role_name_exists", [True, False])
+def test_setup_cross_region(cloud_test_data: Cloud, role_name_exists: bool) -> None:
     mock_get_aws_account = Mock(
         return_value=AnyscaleawsaccountResponse(
             result=AnyscaleAWSAccount(anyscale_aws_account="aws_account_type")
         )
     )
     mock_create_cloud = Mock(return_value=CloudResponse(result=cloud_test_data))
-    mocked_role = mock_role(
-        {
-            "Version": "2012-10-17",
-            "Statement": [
-                {
-                    "Sid": "1",
-                    "Effect": "Allow",
-                    "Principal": {"AWS": ["ARN"]},
-                    "Action": "sts:AssumeRole",
-                    "Condition": {"StringEquals": {"sts:ExternalId": "extid"}},
-                }
-            ],
-        }
-    )
 
+    mock_role = mock_role_with_external_id()
+    mock_role_policy = Mock()
+    mock_role.Policy.return_value = mock_role_policy
+    if role_name_exists:
+        roles = [mock_role, None, mock_role]
+    else:
+        roles = [None, mock_role]
+
+    mock_iam = Mock()
     with patch.multiple(
-        "anyscale.controllers.cloud_controller",
-        _get_role=Mock(return_value=mocked_role),
+        "anyscale.controllers.cloud_controller", _get_role=Mock(side_effect=roles),
+    ), patch.multiple("boto3", resource=Mock(return_value=mock_iam),), patch.multiple(
+        "secrets", token_hex=lambda x: "f" * x * 2
     ):
         cloud_controller = CloudController()
         cloud_controller.api_client.get_anyscale_aws_account_api_v2_clouds_anyscale_aws_account_get = (
@@ -374,8 +364,18 @@ def test_setup_cross_region(cloud_test_data: Cloud) -> None:
         cloud_controller.setup_aws_cross_account_role("us-west-2", "name")
 
     cloud_controller.api_client.get_anyscale_aws_account_api_v2_clouds_anyscale_aws_account_get.assert_called_once()
-    mocked_role.attach_policy.assert_called()
-    mocked_role.AssumeRolePolicy.assert_called()
+
+    assert (
+        mock_role_policy.put.call_count == 2
+    ), "Expected 2 calls, only got {}:\n{}".format(
+        mock_role_policy.put.call_count, mock_role_policy.put.mock_calls
+    )
+    mock_role.AssumeRolePolicy.assert_called()
+
+    mock_iam.create_role.assert_called_once_with(
+        AssumeRolePolicyDocument=ANY, RoleName="anyscale-iam-role-ffffffff"
+    )
+    mock_iam.meta.client.update_role.assert_called_once()
 
 
 @pytest.mark.parametrize(
@@ -409,6 +409,9 @@ def test_setup_aws_ray_role(roles: List[Optional[Mock]]) -> None:
         PolicyArn=AMAZON_ECR_READONLY_ACCESS_POLICY_ARN
     )
     assert 2 == roles[-1].attach_policy.call_count
+    mock_iam.create_instance_profile.assert_called_once_with(
+        InstanceProfileName="ray-autoscaler-v1"
+    )
 
 
 def test_update_cloud_config_by_name(cloud_test_data: Cloud) -> None:
