@@ -253,3 +253,33 @@ def test_terminate(mock_auth_api_client, cluster_list: List[Mock],) -> None:
         cluster_controller.anyscale_api_client.terminate_cluster.assert_called_once_with(
             "mock_cluster_id", {}
         )
+
+
+@pytest.mark.parametrize("cluster_list", [[], [Mock(id="mock_cluster_id")]])
+def test_archive(mock_auth_api_client, cluster_list: List[Mock],) -> None:
+    cluster_controller = ClusterController()
+    cluster_controller._get_project_id_and_cluster_name = Mock(  # type: ignore
+        return_value=("mock_project_id", "mock_cluster_name")
+    )
+    cluster_controller.anyscale_api_client.search_clusters = Mock(  # type: ignore
+        return_value=Mock(results=cluster_list)
+    )
+
+    with pytest.raises(click.ClickException):
+        cluster_controller.archive(None, None, None, None)
+    with pytest.raises(click.ClickException):
+        cluster_controller.archive("cluster_name", "cluster_id", None, None)
+    if len(cluster_list) == 0:
+        with pytest.raises(click.ClickException):
+            cluster_controller.archive("cluster_name", None, "project_id", None)
+    else:
+        cluster_controller.archive("cluster_name", None, "project_id", None)
+        cluster_controller._get_project_id_and_cluster_name.assert_called_once_with(
+            None, "project_id", "cluster_name", None
+        )
+        cluster_controller.anyscale_api_client.search_clusters.assert_called_once_with(
+            {"project_id": "mock_project_id", "name": {"equals": "mock_cluster_name"}}
+        )
+        cluster_controller.anyscale_api_client.archive_cluster.assert_called_once_with(
+            "mock_cluster_id"
+        )
