@@ -304,7 +304,6 @@ def test_convert_cluster_env(mock_auth_api_client) -> None:
 @pytest.mark.parametrize(
     "python_version,ray_version,ml,gpu,expected_image",
     [
-        ("3.6", "1.6.0", True, True, "anyscale/ray-ml:1.6.0-py36-gpu"),
         ("3.7", "1.6.0", False, False, "anyscale/ray:1.6.0-py37"),
         ("3.8", "1.6.0", True, False, "anyscale/ray-ml:1.6.0-py38"),
         ("3.7", "2.0.0dev0", False, True, "anyscale/ray:1.6.0-py37-gpu"),
@@ -336,8 +335,6 @@ def test_select_base_image(
 @pytest.mark.parametrize(
     "python_version,ray_version,ml,gpu,expected_result",
     [
-        ("3.6", "1.6.0", True, True, "ANYSCALE_RAY_ML_1_6_0_PY36_GPU"),
-        ("3.6", "1.5.2", False, True, "ANYSCALE_RAY_1_5_2_PY36_GPU"),
         ("3.7", "1.6.0", False, False, "ANYSCALE_RAY_1_6_0_PY37"),
         ("3.7", "1.4.1", True, True, "ANYSCALE_RAY_ML_1_4_1_PY37_GPU"),
         ("3.8", "1.6.0", True, False, "ANYSCALE_RAY_ML_1_6_0_PY38"),
