@@ -25,8 +25,20 @@ def mock_api_client(command_id_test_data: ExecuteCommandResponse) -> Mock:
     return mock_api_client
 
 
+@pytest.fixture()
+def mock_auth_api_client(mock_api_client: Mock, base_mock_anyscale_api_client: Mock):
+    mock_auth_api_client = Mock(
+        api_client=mock_api_client, anyscale_api_client=base_mock_anyscale_api_client,
+    )
+    with patch.multiple(
+        "anyscale.controllers.base_controller",
+        get_auth_api_client=Mock(return_value=mock_auth_api_client),
+    ):
+        yield
+
+
 def test_anyscale_exec(
-    mock_api_client: Mock, command_id_test_data: ExecuteCommandResponse
+    mock_auth_api_client, command_id_test_data: ExecuteCommandResponse
 ) -> None:
     mock_cluster_config = {"provider": {"default": "value"}, "cluster_name": "cname"}
     mock_get_cluster_config = Mock(return_value=mock_cluster_config)
@@ -36,13 +48,14 @@ def test_anyscale_exec(
     mock_log.format_api_exception.return_value.__enter__ = Mock()
     mock_log.format_api_exception.return_value.__exit__ = Mock()
 
+    exec_controller = ExecController()
+
     with patch.multiple(
         "anyscale.controllers.exec_controller",
         get_cluster_config=mock_get_cluster_config,
         rsync=mock_rsync,
     ), patch.multiple("subprocess", check_call=mock_check_call):
         commands = ["cmd1", "cmd2"]
-        exec_controller = ExecController(api_client=mock_api_client)
         exec_controller._get_session_name_and_id = Mock(  # type: ignore
             return_value=("session_name", "session_id")
         )
@@ -52,7 +65,7 @@ def test_anyscale_exec(
             "session_name", True, False, (1000,), True, True, False, commands
         )
 
-    mock_api_client.execute_interactive_command_api_v2_sessions_session_id_execute_interactive_command_post.assert_called_once_with(
+    exec_controller.api_client.execute_interactive_command_api_v2_sessions_session_id_execute_interactive_command_post.assert_called_once_with(
         session_id="session_id",
         execute_interactive_command_options=ExecuteInteractiveCommandOptions(
             shell_command=" ".join(commands)
@@ -66,7 +79,9 @@ def test_anyscale_exec(
         True,
         False,
     )
-    mock_get_cluster_config.assert_called_once_with("session_name", mock_api_client)
+    mock_get_cluster_config.assert_called_once_with(
+        "session_name", exec_controller.api_client
+    )
     mock_rsync.assert_called_once()
     mock_check_call.assert_called_once()
     exec_controller.log.info.assert_called_once()
