@@ -89,6 +89,15 @@ def patch_jobs_anyscale_api_client(base_mock_anyscale_api_client: Mock):
             "cluster_env": "mock_cluster_env",
             "compute_config": "mock_compute_config",
         },
+        {
+            "entrypoint": "mock_entrypoint",
+            "compute_config": {
+                "cloud_id": "mock_cloud_id",
+                "region": "mock_region",
+                "head_node_type": {"name": "head", "instance_type": "m5.large"},
+                "worker_node_types": [],
+            },
+        },
         {
             "entrypoint": "mock_entrypoint",
             "cluster_env": "mock_cluster_env",
@@ -127,6 +136,10 @@ def test_submit_job(
     mock_get_default_cluster_compute = Mock(
         return_value=Mock(id="mock_compute_config_id")
     )
+    mock_register_compute_template = Mock(
+        return_value=Mock(id="mock_compute_config_id")
+    )
+
     mock_validate_successful_build = Mock()
     mock_get_default_cluster_env_build = Mock(return_value=Mock(id="mock_build_id"))
     with patch(
@@ -138,6 +151,7 @@ def test_submit_job(
         get_build_from_cluster_env_identifier=mock_get_build_from_cluster_env_identifier,
         get_cluster_compute_from_name=mock_get_cluster_compute_from_name,
         get_default_cluster_compute=mock_get_default_cluster_compute,
+        register_compute_template=mock_register_compute_template,
         validate_successful_build=mock_validate_successful_build,
         get_default_cluster_env_build=mock_get_default_cluster_env_build,
     ), patch.multiple(
@@ -172,6 +186,18 @@ def test_submit_job(
     )
     if "cluster_env" not in config_dict and "build_id" not in config_dict:
         mock_get_default_cluster_env_build.assert_called_once_with()
+    if "compute_config" in config_dict:
+        compute_config = config_dict["compute_config"]
+        if isinstance(compute_config, str):
+            mock_get_cluster_compute_from_name.assert_called_once_with(compute_config)
+        elif isinstance(compute_config, dict):
+            mock_register_compute_template.assert_called_once_with(compute_config)
+    elif "cloud" in config_dict:
+        mock_get_default_cluster_compute.assert_called_once_with(
+            config_dict["cloud"], None
+        )
+    elif "compute_config_id" in config_dict:
+        mock_get_default_cluster_compute.assert_not_called()
 
 
 @pytest.mark.parametrize("include_all_users", [False, True])
@@ -787,3 +813,43 @@ def test_wait_for_job_running(mock_auth_api_client) -> None:
     job_controller._get_latest_job_run = Mock(side_effect=get_latest_job_run)  # type: ignore
     job_controller._wait_for_job_running("fake_job_id")
     assert i == 5
+
+
+def test_job_submit_parse_logic(mock_auth_api_client) -> None:
+    job_controller = JobController()
+    job_controller.submit_with_entrypoint = Mock()  # type: ignore
+    job_controller.submit_from_file = Mock()  # type: ignore
+
+    # We are not in a workspace, so entrypoint should not be allowed
+    with pytest.raises(click.ClickException):
+        job_controller.submit(
+            "file", entrypoint=["entrypoint"], is_entrypoint_cmd=False
+        )
+
+    with pytest.raises(click.ClickException):
+        job_controller.submit("file", entrypoint=["entrypoint"], is_entrypoint_cmd=True)
+
+    with pytest.raises(click.ClickException):
+        job_controller.submit(
+            "file", entrypoint=["entrypoint", "commands"], is_entrypoint_cmd=True
+        )
+
+    # Simulate a workspace
+    os.environ["ANYSCALE_EXPERIMENTAL_WORKSPACE_ID"] = "fake_workspace_id"
+
+    # Fails due to is_entrypoint_cmd being False
+    with pytest.raises(click.ClickException):
+        job_controller.submit(
+            "file", entrypoint=["entrypoint"], is_entrypoint_cmd=False
+        )
+
+    job_controller.submit("file", entrypoint=[], is_entrypoint_cmd=False)
+    job_controller.submit_from_file.assert_called_once_with(
+        "file", name=None, description=None
+    )
+    job_controller.submit_from_file.reset_mock()
+
+    job_controller.submit("file", entrypoint=["entrypoint"], is_entrypoint_cmd=True)
+    job_controller.submit_with_entrypoint.assert_called_once_with(
+        ["file", "entrypoint"], None, None
+    )
