@@ -50,17 +50,17 @@ def test_clone_project(
     project_controller._write_sample_compute_config = Mock()  # type: ignore
 
     os_makedirs_mock = Mock(return_value=None)
-    mock_write_project_file_to_disk = Mock(return_value=None)
+    mockwrite_project_file_to_disk = Mock(return_value=None)
     with patch.multiple("os", makedirs=os_makedirs_mock), patch(
-        "anyscale.controllers.project_controller._write_project_file_to_disk"
-    ) as mock_write_project_file_to_disk:
+        "anyscale.controllers.project_controller.write_project_file_to_disk"
+    ) as mockwrite_project_file_to_disk:
         project_controller.clone(project_name=project_test_data.name, owner=owner)
 
     project_controller.api_client.find_project_by_project_name_api_v2_projects_find_by_name_get.assert_called_once_with(
         name=project_test_data.name, _request_timeout=ANY, owner=owner
     )
     os_makedirs_mock.assert_called_once_with(project_test_data.name)
-    mock_write_project_file_to_disk.assert_called_once_with(
+    mockwrite_project_file_to_disk.assert_called_once_with(
         project_test_data.id, project_test_data.name
     )
 
