@@ -1,9 +1,13 @@
 from unittest.mock import Mock
 
-from openapi_client.rest import ApiException  # type: ignore
+from openapi_client.rest import ApiException
 import pytest
 
-from anyscale.client.openapi_client.models import Cloud, CloudListResponse, CloudResponse  # type: ignore
+from anyscale.client.openapi_client.models import (
+    Cloud,
+    CloudListResponse,
+    CloudResponse,
+)
 from anyscale.cloud import get_cloud_id_and_name, get_cloud_json_from_id
 
 
