@@ -19,7 +19,7 @@ from anyscale.client.openapi_client.models.build import Build
 from anyscale.client.openapi_client.models.project import Project
 from anyscale.client.openapi_client.models.project_response import ProjectResponse
 from anyscale.client.openapi_client.models.session import Session
-from anyscale.connect import _is_in_shell, ClientBuilder
+from anyscale.connect import _is_in_shell, _redact_token, ClientBuilder
 from anyscale.sdk.anyscale_client import ComputeTemplateConfig
 from anyscale.util import get_wheel_url, PROJECT_NAME_ENV_VAR
 from anyscale.utils.connect_helpers import (
@@ -1246,3 +1246,11 @@ def test_forward_argument(mock_auth_api_client) -> None:
     assert connect_instance._ray_init_kwargs["log_to_driver"] is False
     assert connect_instance._ray_init_kwargs["logging_level"] == logging.INFO
     assert len(connect_instance._ray_init_kwargs) == 3
+
+
+def test_redact_token() -> None:
+    assert _redact_token("sss_ABCDEFG") == "sss_ABCD********"
+    assert _redact_token("sss_12345" + "0" * 100) == "sss_1234********"
+    assert _redact_token("") == ""
+    assert _redact_token("sss_ABCD") == "sss_ABCD"
+    assert _redact_token("sss_") == "sss_"
