@@ -6,10 +6,8 @@ from pathlib import Path
 import random
 import shutil
 import subprocess
-import sys
 import tempfile
 from typing import Any, AsyncGenerator, Dict, Generator, Optional, Set, Tuple
-from unittest.mock import Mock
 
 import pytest
 import ray
@@ -18,7 +16,6 @@ import anyscale
 from anyscale.utils.ray_conda import get_conda_activate_commands
 from anyscale.utils.runtime_env import (
     _calc_pkg_for_working_dir,
-    _get_conda_dict,
     _get_conda_env_path,
     _read_dir_meta,
     ensure_runtime_env_setup,
@@ -88,62 +85,6 @@ def random_working_dir() -> Generator[Tuple[Path, Set[Path], Set[Path]], None, N
         yield (root, big_files, small_files)
 
 
-def test_get_conda_dict() -> None:
-    """This test is to check whether anyscale/ray[default]/python version
-    got injected correctly in anyscale product code path.
-    """
-    with tempfile.TemporaryDirectory() as tmp_dir:
-        with open("requirements.txt", "w") as t:
-            t.write(
-                """pip-install-test==0.5
-ray"""
-            )
-        import ray.workers.setup_runtime_env
-
-        current_ray_pip_specifier = Mock()
-        current_ray_pip_specifier.return_value = "ray==test"
-        ray.workers.setup_runtime_env.current_ray_pip_specifier = (
-            current_ray_pip_specifier
-        )
-        py_version = ".".join(map(str, sys.version_info[:3]))
-        test_wheel = "ANYSCALE_TEST_WHEEL_ADDR"
-        # With this flag on, it'll use user wheel for anyscale
-        # this is useful for testing
-        os.environ["ANYSCALE_USER_WHEEL"] = test_wheel
-        pip_txt = "test1\test2"
-        runtime_env = {
-            "working_dir": ".",
-            "pip": pip_txt,
-        }
-
-        conda_dict = _get_conda_dict(runtime_env, tmp_dir)
-        deps = conda_dict["dependencies"]
-        assert deps[0] == "pip"
-        # anyscale is always put at the beginning
-        pips = deps[1]["pip"]
-        assert len(pips) == 4
-        pips[3] = Path(pips[3].split()[1]).read_text()
-        assert pips == [test_wheel, "ray==test", "ray[default]", pip_txt]
-        assert deps[2] == f"python={py_version}"
-
-        # Test the case when it's off and use anyscale.__version__
-        # automatically
-        os.environ.pop("ANYSCALE_USER_WHEEL")
-        conda_dict = _get_conda_dict(runtime_env, tmp_dir)
-        deps = conda_dict["dependencies"]
-        assert deps[0] == "pip"
-        pips = deps[1]["pip"]
-        assert len(pips) == 4
-        pips[3] = Path(pips[3].split()[1]).read_text()
-        assert pips == [
-            f"anyscale=={anyscale.__version__}",
-            "ray==test",
-            "ray[default]",
-            pip_txt,
-        ]
-        assert deps[2] == f"python={py_version}"
-
-
 def test_split_no_base(random_working_dir: Tuple[Path, Set[Path], Set[Path]]) -> None:
     # Test splitting when there is no base dir
     (working_dir, big_files, small_files) = random_working_dir
