@@ -1,5 +1,5 @@
 import time
-from typing import Any, Dict
+from typing import Any
 from unittest.mock import patch
 
 import pytest
@@ -9,7 +9,6 @@ from anyscale.util import (
     _ray_version_major_minor,
     _update_external_ids_for_policy,
     extract_versions_from_image_name,
-    number_of_external_ids_in_policy,
     poll,
     sleep_till,
     updating_printer,
@@ -152,47 +151,6 @@ def test_update_external_ids_for_policy(statement_policy, expected_conditions):
         assert new["Condition"] == expected
 
 
-@pytest.mark.parametrize(
-    "statement,num_ext_ids",
-    [
-        pytest.param(
-            [STATEMENT_TEMPLATE, STATEMENT_TEMPLATE],
-            0,
-            id="MultipleStatements,NoExtID",
-        ),
-        pytest.param(
-            [
-                {
-                    "Condition": {"StringEquals": {"sts:ExternalId": "old_id"}},
-                    **STATEMENT_TEMPLATE,  # type: ignore
-                },
-                STATEMENT_TEMPLATE,
-            ],
-            1,
-            id="OneExternalID,MultipleStatements",
-        ),
-        pytest.param(
-            [
-                {
-                    "Condition": {
-                        "StringEquals": {"sts:ExternalId": ["id_one", "id_two"]}
-                    },
-                    **STATEMENT_TEMPLATE,  # type: ignore
-                }
-            ],
-            2,
-            id="ExternalIdList",
-        ),
-    ],
-)
-def test_number_of_external_ids_in_policy(statement: Dict[str, Any], num_ext_ids: int):
-    policy = {
-        "Statement": statement,
-        "Version": "2012-10-17",
-    }
-    assert number_of_external_ids_in_policy(policy) == num_ext_ids
-
-
 @pytest.mark.parametrize(
     "image_name, expected, exception_substr",
     [
